@@ -150,6 +150,8 @@ class PromptManager:
             # Function implementation ...
             get_token_distributions = []
             data_chunks_list = chunk_source_code(total_chunk_data, fictitious_chunk_token_length)
+            while '' in data_chunks_list:
+                data_chunks_list.remove('')
             total_chunks = len(data_chunks_list)
 
             for i, chunk_data in enumerate(data_chunks_list):
@@ -160,6 +162,7 @@ class PromptManager:
                                            prompt_token_desired=prompt_token_desired,
                                            initial_completion_token_length=initial_completion_token_length,
                                            completion_token_desired=completion_token_desired)
+                
                 get_token_distributions.append(chunk_js)
 
             if total_chunks == 0:
@@ -213,7 +216,7 @@ class PromptManager:
                                                          completion_token_desired=completion_token_desired,
                                                          initial_completion_token_length=initial_completion_token_length,
                                                          chunk_type=self.chunk_type))
-       
+        
         return token_distributions
             
     def create_prompt_guide(self,
