@@ -1074,7 +1074,11 @@ class GptManager:
             if os.path.isfile(file_path):
                 try:
                     contents = self.read_file_contents(file_path)  # Assuming read_file_contents is defined to handle different file types
-                    self.window_mgr.update_value(key=self.script_event_js['-FILE_TEXT-'], value=safe_json_loads(contents))
+                    contents = safe_json_loads(contents)
+                    
+                    if isinstance(contents,dict) and self.window_mgr.get_from_value(text_to_key('format json to string', section='responses')):
+                        contents = format_json_key_values(contents)
+                    self.window_mgr.update_value(key=self.script_event_js['-FILE_TEXT-'], value=contents)
                     self.chunk_title = os.path.basename(file_path)
                     self.window_mgr.update_value(key=text_to_key('-CHUNK_TITLE-', section='files'), value=self.chunk_title)
                 except Exception as e:
