@@ -1,5 +1,4 @@
 import inspect
-import abstract_ai
 def get_docstrings(module):
     docstrings = {}
     for name, obj in inspect.getmembers(module):
@@ -8,4 +7,4 @@ def get_docstrings(module):
     return docstrings
 
 docstrings = get_docstrings(abstract_ai)
-input(docstrings)
+
